import { View, RichText, Image } from "@tarojs/components";
import { getSign, getUserAgreement } from "../../service";
import { AtCheckbox } from "taro-ui";
import "./index.less";
import Taro from "@tarojs/taro";
import close from "../../images/productDetail/close.png";
import { useState, useEffect } from "react";

// 签约模态框组件
export default function signModal(props) {
  const { isOpened, onClose, isMine } = props;
  const [agreement, setAgreement] = useState("");
  const [isChecked, setIsChecked] = useState(false);
  const checkboxOption = [
    {
      value: "agree",
      label: "",
    },
  ];
  // 获取协议
  const getAgreement = async () => {
    const res = await getUserAgreement({
      type: 3,
    });
    setAgreement(res.content);
  };
  useEffect(() => {
    getAgreement();
  }, []);
  // 同意协议
  const handleCheckboxChange = (value) => {
    setIsChecked(value.length > 0);
  };
  // 签约
  const handleSign = async () => {
    const res = await getSign({
      type: 1,
    });
    // 签约后更新用户信息
    Taro.setStorageSync("userInfo", res);
    Taro.showToast({
      title: '签约成功',
      icon: "none",
    });
    onClose();
  };
  // 关闭弹窗
  const closeModal = () => {
    if (isChecked) {
      Taro.setStorageSync("isShowSign", false);
    }
    onClose();
  };
  return (
    <>
      {isOpened && (
        <View className="modal-container">
          <View className="modal-mask" />
          <View className="modal-content">
            <Image onClick={closeModal} src={close} className="close-icon" />
            <View className="content-box">
              <Image src='https://yushi.tos-cn-beijing.volces.com/calculator/sign.png' className="sign-icon" />
              <View className="sign-title">
                鱼市招募推广者！自购享折扣，省钱多多；分享有佣金，赚钱轻松。速来开启共赢之旅!
              </View>
              <View onClick={handleSign} className="btn">
                签约
              </View>
              {!isMine && (
                <View className="checkbox-container">
                  <AtCheckbox
                    options={checkboxOption}
                    selectedList={isChecked ? ["agree"] : []}
                    onChange={handleCheckboxChange}
                  />
                  <View className="checkbox-text">不再提示</View>
                </View>
              )}
            </View>
          </View>
        </View>
      )}
    </>
  );
}
