import { Component } from "react";
import { View, Image, Text, Button, Input } from "@tarojs/components";
import Taro from "@tarojs/taro";
import "./index.less";

export default class Index extends Component {
  state = {
    shareTitle: "", //分享标题
    productDetail: {}, //商品详情
    isSeckill: false, //是否是秒杀商品
    shareJump: "", //分享链接
    tagTitle: "", //标签标题
  };
  componentDidMount() {
    const { isSeckill, shareJump, tagTitle, productDetail } =
      Taro.getCurrentInstance().router.params;

    this.setState({
      isSeckill: isSeckill === "true",
      shareJump,
      tagTitle,
      productDetail: JSON.parse(decodeURIComponent(productDetail)),
      shareTitle: JSON.parse(decodeURIComponent(productDetail)).item_title,
    });
  }
  // 设置分享标题
  handleShareTitleChange = (newTitle) => {
    this.setState({
      shareTitle: newTitle,
    });
  };
  // 保存图片到手机
  handleSaveImage = () => {
    Taro.getSetting({
      success: (res) => {
        if (!res.authSetting["scope.writePhotosAlbum"]) {
          Taro.authorize({
            scope: "scope.writePhotosAlbum",
            success: () => {
              this.saveImage();
            },
            fail: () => {
              Taro.showModal({
                title: "提示",
                content: "需要您授权保存图片到相册",
                success: (modalRes) => {
                  if (modalRes.confirm) {
                    Taro.openSetting();
                  }
                },
              });
            },
          });
        } else {
          this.saveImage();
        }
      },
    });
  };

  saveImage = () => {
    Taro.downloadFile({
      url: this.state.productDetail.images[0].img,
      success: (res) => {
        console.log(res);

        Taro.saveImageToPhotosAlbum({
          filePath: res.tempFilePath,
          success: () => {
            Taro.showToast({
              title: "保存成功",
              icon: "success",
            });
          },
          fail: () => {
            Taro.showToast({
              title: "保存失败",
              icon: "none",
            });
          },
        });
      },
      fail: () => {
        Taro.showToast({
          title: "图片下载失败",
          icon: "none",
        });
      },
    });
  };
  // 配置分享内容
  onShareAppMessage() {
    return {
      title: this.state.shareTitle || this.state.productDetail.item_title,
      path: `/pages/indexSub/productDetail/index?id=${this.state.productDetail.id}&&isShare=true&&isSeckill=${this.state.isSeckill}&&shareJump=${this.state.shareJump}&&tagTitle=${this.state.tagTitle}&&shareType=1`,
      imageUrl: this.state.productDetail.images[0].img,
    };
  }
  render() {
    const { productDetail } = this.state;
    return (
      <View className="index">
        {/* 图片素材盒子 */}
        <View className="image-box">
          <View className="image-box-top">
            <View className="image-box-title">图片素材</View>
            <View className="image-box-save" onClick={this.handleSaveImage}>
              保存图片
            </View>
          </View>
          {productDetail.images && (
            <View className="image-box-content">
              {this.state.productDetail.images.map((item, index) => (
                <Image
                  className="image-box-content-item"
                  key={index}
                  src={item.img}
                  mode="aspectFill"
                />
              ))}
            </View>
          )}
        </View>
        {/* 文案素材盒子 */}
        <View className="text-box">
          <View className="text-box-top">
            <View className="text-box-title">文案素材</View>
            <View className="text-box-save">复制全部内容</View>
          </View>
          <View className="text-box-content">
            {/* 商品标题盒子 */}
            <View className="text-box-content-title">
              <View className="text-box-content-title-top">
                <View className="text-box-content-title-top-title">
                  商品标题
                </View>
                <View className="text-box-content-title-top-copy">
                  复制标题
                </View>
              </View>
              {/* 分享标题输入框 */}
              <Input
                onInput={this.handleShareTitleChange}
                className="input"
                value={this.state.shareTitle}
              />
            </View>
            {/* 商品链接盒子 */}
            <View className="text-box-content-link">
              <View className="text-box-content-link-top">
                <View className="text-box-content-link-top-title">
                  商品链接
                </View>
              </View>
              {/* 商品链接 */}
              <View className="text-box-content-link-bottom">
                <Input
                  onInput={this.handleShareTitleChange}
                  className="linkInput"
                  value={this.state.shareTitle}
                  disabled
                />
                <View className="copy-box">
                  <View className="copy-box-line"></View>
                  <Image className="copy-box-icon" src='https://yushi.tos-cn-beijing.volces.com/productDetail/copy.png' />
                </View>
              </View>
            </View>
          </View>
        </View>
        {/* 分享按钮 */}
        <Button className="share-button" openType="share" onClick={this.handleShare}>
          直接分享商品卡片到聊天框
        </Button>
      </View>
    );
  }
}
