import { Component } from "react";
import { View, Text, Image } from "@tarojs/components";
import "./index.less";
import { AtDivider, AtActivityIndicator } from "taro-ui";
import level from "../../../images/partner/level.png";
import Taro from "@tarojs/taro";
import vip from "../../../images/earningsOrder/vip.png";
import { getPartnerDetail } from "../../../service";
export default class Index extends Component {
  state = {
    orderList: [],//订单列表
    id: "",//伙伴id
    page: 1, //页数
    loading: false, //加载状态
    totalPages: 1, // 添加总页数
    isNoMore: false,
  };
  componentDidMount() {
    const { id } = Taro.getCurrentInstance().router.params;
    this.setState({ id }, () => {
      this.getPartnerDetail(true);
    });
  }
  // 获取伙伴详情
  getPartnerDetail = async (isRefresh = false) => {
    const { page } = this.state;
    this.setState({ loading: true });

    const res = await getPartnerDetail({
      partner_id: this.state.id,
      page,
      page_size: 10,
    });

    this.setState((prevState) => ({
      orderList: isRefresh
        ? res.income_list
        : [...prevState.orderList, ...res.income_list],
      partnerDetail: res.partner_user,
      totalPages: res.total_pages,
      loading: false,
      isNoMore: res.total_pages <= page,
    }));
  };
  // 复制
  handleCopy = async (text) => {
    try {
      await Taro.setClipboardData({
        data: text,
      });
      Taro.showToast({
        title: "内容已复制",
        icon: "success",
        duration: 2000,
      });
    } catch (error) {
      Taro.showToast({
        title: "复制失败",
        icon: "error",
        duration: 2000,
      });
    }
  };
  // 页面上拉触底
  onReachBottom = () => {
    const { page, totalPages, loading } = this.state;
    if (page < totalPages && !loading) {
      this.setState(
        (prevState) => ({ page: prevState.page + 1 }),
        () => this.getPartnerDetail()
      );
    }
  };
  render() {
    const { orderList, loading, isNoMore, partnerDetail } = this.state;
    return (
      <View className="index">
        <View className="container">
          {partnerDetail && (
            <View className="header">
              <View className="header-left">
                <Text className="name">{partnerDetail.name}</Text>
                {/* <View className="level">
                  <Image className="level-icon" src={level} />
                  <Text className="level-text">导购员</Text>
                </View> */}
              </View>
              <View className="header-right">
                <Image className="header-right-avatar" src={partnerDetail.icon} />
              </View>
            </View>
          )}
          {/* 个人资料 */}
          {partnerDetail && (
            <View className="personal-info">
              <View className="info-top">
                <View className="personal-info-item">
                  <Text className="personal-info-item-label">累计贡献返利</Text>
                  <Text className="personal-info-item-value">￥{partnerDetail.all_income_rebate}</Text>
                </View>
                <View className="line"></View>
                {/* <View className="personal-info-item">
                <Text className="personal-info-item-label">累计贡献管理奖</Text>
                <Text className="personal-info-item-value">￥0.00</Text>
              </View> */}
                <View className="personal-info-item">
                  <Text className="personal-info-item-label">手机号</Text>
                  <Text className="personal-info-item-value">{partnerDetail.phone}</Text>
                </View>
              </View>
              <View className="line-column"></View>
              <View className="info-bottom">
                {/* <View className="personal-info-item">
                  <Text className="personal-info-item-label">手机号</Text>
                  <Text className="personal-info-item-value">{partnerDetail.phone}</Text>
                </View> */}
                <View style={{width: '46%'}} className="personal-info-item">
                  <Text className="personal-info-item-label">推荐绑定时间</Text>
                  <Text className="personal-info-item-value">
                    {partnerDetail.start_date}
                  </Text>
                </View>
                <View className="line"></View>
              </View>
            </View>
          )}
          {/* 订单列表 */}
          <View className="order-list">
            {orderList && orderList.map((item, index) => (
              <View className="order-item" key={index}>
                {/* 订单信息 */}
                <View className="order-info">
                  <View className="order-details">
                    <View className="detail-item">
                      <Text className="label">订单编号:</Text>
                      <Text className="value">{item.order_number}</Text>
                      <Text
                        className="copy-text"
                        onClick={() => this.handleCopy(item.order_number)}
                      >
                        复制
                      </Text>
                    </View>
                    <View className="detail-item">
                      <Text className="label">下单时间:</Text>
                      <Text className="value">{item.pay_time}</Text>
                    </View>
                  </View>
                  {/* <View className="member-info">
                    <Image className="member-icon" src={vip} />
                    <Text className="member-text">闲鱼会员</Text>
                  </View> */}
                </View>

                {/* 产品信息 */}
                <View className="product-info">
                  <Image
                    mode="aspectFill"
                    className="product-image"
                    src={item.item_pic_url}
                  />
                  <View className="product-details">
                    <Text className="product-name">{item.item_title}</Text>
                    <View className="promotion-info">
                      <View className="tag">预估收入</View>
                      <Text className="amount">¥{item.assess_amount_text_promotion}</Text>
                    </View>
                    <View className="payment-info">
                      <Text className="label">实付金额:</Text>
                      <Text className="amount">¥{item.actual_paid_fee}</Text>
                    </View>
                  </View>
                </View>
              </View>
            ))}
          </View>
          {orderList && orderList.length === 0 && (
            <AtDivider
              content="暂无成交订单"
              fontColor="#B5B5B5"
              lineColor="#D8D8D8"
            />
          )}
          {/* 加载中 */}
          {loading && (
            <View className="loading">
              <AtActivityIndicator
                content="加载中..."
                isOpened={loading}
                mode="center"
                color="#fdf764"
              />
            </View>
          )}
          {/* 没有更多 */}
          {isNoMore && (
            <View className="no-more">
              <AtDivider
                fontSize={18}
                fontColor="#949494"
                content="我是有底线的"
              />
            </View>
          )}
        </View>
      </View>
    );
  }
}
