import { Component } from "react";
import Taro from "@tarojs/taro";
import { View, Text, Image, Button } from "@tarojs/components";
import { AtList, AtListItem } from "taro-ui";
import { getUserInfo, getMineData } from "../../service";
import "./index.less";
import loginOut from "../../images/mine/loginOut.png";
import edit from "../../images/mine/edit.png";
import norm from "../../images/mine/norm.png";
import sign from "../../images/mine/sign.png";
import SignModal from "../../components/signModal";
import levelOne from "../../images/mine/levelOne.png";
import levelTwo from "../../images/mine/levelTwo.png";
import levelThree from "../../images/mine/levelThree.png";
import levelFour from "../../images/mine/levelFour.png";
import levelFive from "../../images/mine/levelFive.png";
export default class Index extends Component {
  state = {
    userInfo: {}, //用户信息
    mineData: {}, //我的页面数据
    isOpened: false, //是否打开弹窗
  };
  // 退出登录
  handleLogout = () => {
    Taro.showModal({
      title: "",
      content: "退出后，请重新登录!",
      cancelText: "暂不退出",
      confirmText: "退出登录",
      cancelColor: "#000000",
      confirmColor: "#F6C71A",
      success: function (res) {
        if (res.confirm) {
          Taro.removeStorageSync("session_key");
          Taro.removeStorageSync("loginInfo");
          Taro.removeStorageSync("userInfo");
          console.log("用户点击退出登录");
        }
      },
    });
  };
  componentDidShow() {
    const session_key = Taro.getStorageSync("session_key");
    if (session_key) {
      this.getUserInfo();
      this.getMineData();
    }
  }
  // 获取用户信息
  getUserInfo = async () => {
    const res = await getUserInfo();
    Taro.setStorageSync("userInfo", res);
    this.setState({
      userInfo: res,
    });
  };
  // 获取我的页面数据
  getMineData = async () => {
    const res = await getMineData();
    this.setState({
      mineData: res,
    });
  };
  // 去登录
  Login = () => {
    if (!Taro.getStorageSync("session_key")) {
      Taro.reLaunch({
        url: "/pages/login/index",
      });
    }
  };
  // 合作签约
  handleSign = () => {
    let session_key = Taro.getStorageSync("session_key");
    if (session_key && this.state.userInfo.user_identity === 0) {
      this.setState({
        isOpened: true,
      });
    } else {
      Taro.showToast({
        title: "您已签约",
        icon: "none",
      });
    }
  };
  render() {
    const { userInfo, isOpened, mineData } = this.state;
    return (
      <View className="index">
        {/* 个人信息 */}
        <View className="info">
          <Image
            src={userInfo.icon ? userInfo.icon : 'https://yushi.tos-cn-beijing.volces.com/mine/avatar.png'}
            className="avatar"
          />
          <View className="info-right">
            <View className="user-info">
              <View onClick={this.Login} className="name">
                {userInfo.name ? userInfo.name : "去登录"}
                {userInfo.user_identity !== 0 && (
                  <View className="level-box">
                    <Image
                      src={
                        userInfo.user_identity === 1
                          ? levelOne
                          : userInfo.user_identity === 2
                          ? levelTwo
                          : userInfo.user_identity === 3
                          ? levelThree
                          : userInfo.user_identity === 4
                          ? levelFour
                          : userInfo.user_identity === 5
                          ? levelFive
                          : levelOne
                      }
                      className="level-icon"
                    />
                    <Text
                      className="level-text"
                      style={{
                        color:
                          userInfo.user_identity === 1
                            ? "#8AA6F1"
                            : userInfo.user_identity === 2
                            ? "#0077F6"
                            : userInfo.user_identity === 3
                            ? "#7D00E1"
                            : userInfo.user_identity === 4
                            ? "#FE585A"
                            : userInfo.user_identity === 5
                            ? "#E87D12"
                            : "#8AA6F1",
                      }}
                    >
                      Lv {userInfo.user_identity}
                    </Text>
                  </View>
                )}
              </View>
              <View className="account">{userInfo.id ? userInfo.id : ""}</View>
            </View>
            <Image
              onClick={() =>
                Taro.navigateTo({ url: `/pages/mineSub/infoEdit/index` })
              }
              className="edit-icon"
              src={edit}
            ></Image>
          </View>
        </View>
        <Button onClick={() => Taro.navigateTo({ url: '/pages/indexSub/activity/index' })}>
          活动页面
        </Button>
        {/* 我的推荐人 */}
        {mineData.user_relations?.id && (
          <View className="recommend-box">
            <View className="recommend-title">
              <Text className="recommend-title-text">我的推荐人</Text>
            </View>
            <View className="line"></View>
            <View className="recommend-content">
              <Image
                className="recommend-avatar"
                src={mineData.user_relations.icon}
              />
              <View className="recommend-info">
                <Text className="recommend-name">
                  {mineData.user_relations.name}
                </Text>
                <Text className="recommend-id">
                  ID: {mineData.user_relations.id}
                </Text>
              </View>
            </View>
          </View>
        )}
        {/* 功能 */}
        <View className="function">
          <AtList hasBorder={false}>
            <AtListItem
              hasBorder={false}
              onClick={this.handleSign}
              title="合作签约"
              arrow="right"
              thumb={sign}
            />
            <AtListItem
              hasBorder={false}
              onClick={() =>
                Taro.navigateTo({
                  url: `/pages/mineSub/userSpecification/index`,
                })
              }
              title="用户规范"
              arrow="right"
              thumb={norm}
            />
            {/* <View className="line"></View> */}
            {/* <AtListItem
              hasBorder={false}
              title="退出登录"
              arrow="right"
              thumb={loginOut}
              onClick={this.handleLogout}
            /> */}
          </AtList>
        </View>
        {/* 签约弹窗 */}
        <SignModal
          isMine={true}
          isOpened={isOpened}
          onClose={() => this.setState({ isOpened: false })}
        />
      </View>
    );
  }
}
